#!/bin/sh 
# -- BEGIN COPYRIGHT --
# IBM SecureWay Firewall Version 4.2
# Licensed Materials - Property of IBM
#
# 5697-F48
#
# (C) Copyright IBM Corp. 1985, 1994, 1999 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# -- END COPYRIGHT --

#
# Program File: config_logfile_adapter.sh
#

PRODUCT=SECUREWAY_FIREWALL
REG="reg2.exe"

# Description: converts back slashed to forward slashes
#
# Usage:
#        to_unix $TARGET_PATH TARGET_PATH

to_unix()
{
  if [ "$INTERP" = "w32-ix86" ] ; then
    UNIX_PATH=`echo $1 | sed -e 's|\\\\|/|g'`
  else
    UNIX_PATH=`printf "%s\n" "$1" | sed -e 's|\\\\|/|g'`
  fi

  eval $2=$UNIX_PATH
}

#
# does the firewall service exist?
#  0 = yes
#  1 = no
#

fw_service_exists()
{
  exists=`net start | grep fwLogfile`
  if [ "$exists" ] ; then
    return 0
  else
    return 1
  fi
}
 
# make the directory structure for the lf adapter
#
# argument:  base dir, dependent on os and whether
# or not the fw server is an endpoint or managed node

mkdir_struct()
{
  # clean up first
  if [ -d "$1/lfa" ] ; then
    rm -rf $1/lfa
  fi
  # won't clean up on NT, so check to make sure dir
  # doesn't already exist
  if [ ! -d "$1/lfa" ] ; then
    mkdir $1/lfa
  fi
  if [ ! -d "$1/lfa/conf" ] ; then
    mkdir $1/lfa/conf
  fi
  if [ ! -d "$1/lfa/lib" ] ; then
    mkdir $1/lfa/lib
  fi
  if [ ! -d "$1/lfa/servEXEs" ] ; then
    mkdir $1/lfa/servEXEs
  fi
}

# any files that we haven't modified, copy over
# to the correct place in the hierarchy
#
# arguments:  
#            1--base dir, dependent on os and whether
#            or not the fw server is an endpoint or 
#            managed node
#            2--where to copy to create the correct
#               hierarchy
#            3--either nt or aix
#  

copy_files()
{

  cp -f $1/fwLogfile.trace $2/lfa/conf
  cp -f $1/fwLogfile.map $2/lfa/conf
  cp -f $1/eofFile.dne $2/lfa/eofFile.dne
  cp -f $1/fwLogfile.pl $2/lfa
  cp -f $1/system.config $2/lfa
  if [ x"$3" = x"nt" ] ; then
    # code fix 3/29/00, postemsg, when on endpoint, will be in same
    # directory as all the other files, and will be in
    # $BINDIR/bin on a managed node
    # cp -f $BINDIR/../lcf_bundle/bin/w32-ix86/bin/postemsg.exe $2/lfa
    if [ x"$EP" = x"TRUE" ] ; then
      cp -f $1/postemsg.exe $2/lfa
    else
      cp -f $BINDIR/bin/postemsg.exe $2/lfa
    fi 
    cp -f $1/startp.exe $2/lfa
    cp -f $1/reg.exe $2/lfa/servEXEs
    cp -f $1/servMgr.exe $2/lfa/servEXEs
    # make sure srvany.exe doesn't exist; it will still exist
    # when this job is run more than once 
    if [ ! -f $2/lfa/servEXEs/srvany.exe ] ; then
      cp -f $1/srvany.exe $2/lfa/servEXEs
    fi
    cp -f $1/mkserv.bat $2/lfa/mkserv.bat
  else
    # code fix 3/29/00, see above fix
    if [ x"$EP" = x"TRUE" ] ; then
      #cp -f $BINDIR/../lcf_bundle/bin/w32-ix86/bin/postemsg $2/lfa/postemsg.aix
      cp -f $1/postemsg $2/lfa/postemsg.aix
      cp -f $1/postemsg $2/lfa/postemsg
    else
      cp -f $BINDIR/bin/postemsg $2/lfa/postemsg.aix
      cp -f $BINDIR/bin/postemsg $2/lfa/postemsg
    fi
  fi
  cp -f $1/Logfile.pl $2/lfa/lib
  cp -f $1/tec.pl $2/lfa/lib
  cp -f $1/trace.pl $2/lfa/lib
  cp -f $1/fwLogfile.conf $2/lfa/conf
  cp -f $1/post.cfg $2/lfa/post.cfg

}

# $1 = base directory of plus module installation
#      or where dependencies have put files on
#      endpoints
# $2 = on endpoints, we'll need to do all file
#      copying over to a "~"-less directory
 
get_directory()
{

  TEMP=$DBDIR/tmp
  #echo "THIS IS AAAAA $1"
  FW_DIR=`$1/$REG -p "SOFTWARE/IBM/IBMFirewall/4.2" | grep RootDirectory | awk -F= '{print $2}'`
  to_unix $FW_DIR FW_DIR
  SLOG="$FW_DIR/config/syslog.conf"
  cp $SLOG $2
  SYSLOG="$2/syslog.conf"
  LF=`cat $SYSLOG | awk '{print $2}'`
  to_unix "$LF" LF
  cp $LF $2
  LOGFILE="$2/local4.log"

}

update_config()
{

    updateConfig.pl $1/lfa/conf/fwLogfile.conf ServerName " $TEC_SERVER"
    updateConfig.pl $1/lfa/conf/fwLogfile.conf EOFfile " $1/lfa/EOFfile.dne"
    updateConfig.pl $1/lfa/conf/fwLogfile.conf PortNo " $NT_TEC_PORT"
    updateConfig.pl $1/lfa/conf/fwLogfile.conf CONFfile " $SYSLOG"
    updateConfig.pl $1/lfa/conf/fwLogfile.conf LOGFILES " $LOGFILE"
    updateConfig.pl $1/lfa/post.cfg ServerLocation "$TEC_SERVER"
    updateConfig.pl $1/lfa/post.cfg ServerPort "$TEC_PORT"
    updateConfig.pl $1/lfa/mkserv.bat "set perlLocation" "$PERL_LOC"
    updateConfig.pl $1/lfa/mkserv.bat "set CWD" "$1/lfa"

}

# ----------------------------------------------------------------------
# Discover if we are on an LCF endpoint.
# ----------------------------------------------------------------------
if [ "x$LCF_BINDIR" != "x" ]; then
  EP=TRUE
  if [ "x$OS" = "xWindows_NT" ]; then
    ETC=$SystemRoot/system32/drivers/etc/Tivoli
    if [ ! -d "$ETC" ] ; then
      mkdir -p $ETC
    fi
    ETCA="$ETC"
    to_unix $ETCA ETCA
    NULL=nul
    LCF_TOOLS="$LCF_BINDIR/../tools"
    LCF_TOOLS=`echo $LCF_TOOLS | sed -e 's|\\\\|/|g'`
    LCF_TOOLS=`echo $LCF_TOOLS | sed 's/Program Files/Progra~1/g'`
    LCF_TOOLSDIR="$LCF_TOOLS"
    export LCF_TOOLSDIR 
    get_directory "$LCF_TOOLSDIR" "$ETCA"
  else
    ETC=/etc/Tivoli
    if [ ! -d "$ETC" ] ; then
      mkdir -p $ETC
    fi
    if [ ! "$LCF_TOOLSDIR" ] ; then
      LCF_TOOLSDIR="$LCF_BINDIR/../tools"
    fi  
    NULL=/dev/null
  fi
  TEMP=/tmp
else
  EP=FALSE
fi

if [ x"$EP" = x"FALSE" ] ; then
  if [ -f $SystemRoot/system32/drivers/etc/Tivoli/setup_env.sh ] ; then
          . $SystemRoot/system32/drivers/etc/Tivoli/setup_env.sh
          PROD_DIR=$BINDIR/../generic_unix/TME/PLUS/SECUREWAY_FIREWALL
          get_directory "$PROD_DIR" "$PROD_DIR" 
  else
          . /etc/Tivoli/setup_env.sh
          PROD_DIR=$BINDIR/../generic_unix/TME/PLUS/SECUREWAY_FIREWALL
	  TEMP=/tmp
  fi
  OSERV=`objcall 0.0.0 get_oserv`
  INST_DIR=`objcall $OSERV query install_dir`
  PATH=$INST_DIR/generic_unix/TME/PLUS/SECUREWAY_FIREWALL:$BINDIR/AEF:$PATH
  export PATH
fi

#  Debugging code: by creating a file called /tmp/${PRODUCT}debug in
#     the appropriate TEMP directory, the output of scripts is
#     set to debugging (should appear in stderr for the task)

DEBUGFILE=$TEMP/${PRODUCT}debug

if [ -f $DEBUGFILE ]; then
  set -x
fi

# find out if TEC Server, TEC Server port, and perl
# location have been entered; also find out if they
# just want to start or stop the lfa

if [ x"$1" = x"START_LFA" -a x"$2" = x -a x"$3" = x ] ; then
  if [ "x$OS" = "xWindows_NT" ]; then
    net start fwLogfile
    if [ $? -ne 0 ] ; then
      echo Error in starting the SecureWay Firewall Plus for Tivoli logfile adapter!
      exit 1
    fi
    exit 0
  else
    if [ x"$EP" = x"FALSE" ] ; then
      cd $BINDIR/../generic_unix/TME/PLUS/SECUREWAY_FIREWALL/lfa
    else
      cd /etc/Tivoli/lfa
    fi 
    ADAPTER_HOME=`pwd`
    export ADAPTER_HOME
    $PERL_LOC ./fwLogfile.pl
    if [ $? -eq 0 ] ; then
      echo Started the SecureWay Firewall Plus for Tivoli logfile adapter!
      exit 0
    else
      echo Failed to start the SecureWay Firewall Plus for Tivoli logfile adapter!
      exit 1
    fi 
  fi   
elif [ x"$1" = x"STOP_LFA" -a x"$2" = x -a x"$3" = x ] ; then
  if [ "x$OS" = "xWindows_NT" ]; then
    net stop fwLogfile
    if [ $? -ne 0 ] ; then
      echo Error in stopping the SecureWay Firewall Plus for Tivoli logfile adapter!
      exit 1
    fi
    exit 0
  else
    PID=`ps -ef | grep fwLogfile | grep -v "grep fwLogfile" | awk '{print $2}'`
    kill -9 $PID
    if [ $? -eq 0 ] ; then
      echo "Stopped SecureWay Plus for Tivoli logfile adapter!"
      exit 0
    else
      echo "Error in stopping SecureWay Plus for Tivoli logfile adapter!"
      exit 1
    fi
  fi      
fi

if [ x"$1" != x ] ; then
  TEC_SERVER="$1"
else
  echo "You need to specify the TEC Server!"
  echo "Please rerun this task!"
  exit 1
fi

if [ x"$2" != x ] ; then
  TEC_PORT="$2"
else
  echo "You need to specify the TEC Server Port!"
  echo "Please rerun this task!"
  exit 1
fi

if [ x"$3" != x ] ; then
  PERL_LOC="$3"
else
  echo "You need to specify the location to the perl 5"
  echo "binary (and include the perl executable in the"
  echo "path!  Please rerun this task!"
  exit 1
fi
 
#Must unset CHILD_OF_OSERV or it will end up in the firewall environment
#and could really hose up the CLI calls back to TME
unset CHILD_OF_OSERV

#
# scenarios for setting up the logfile adapter
# 1) FW Server = MN, NT
# 2) FW Server = MN, AIX
# 3) FW Server = EP, NT
# 4) FW Server = EP, AIX
# 

PROD_DIR=$BINDIR/../generic_unix/TME/PLUS/SECUREWAY_FIREWALL
NT_TEC_PORT=5529

if [ x"$EP" = x"FALSE" ] ; then
  if [ -f $SystemRoot/system32/drivers/etc/Tivoli/setup_env.sh ] ; then
  # scenario 1)
    mkdir_struct "$PROD_DIR"
    copy_files "$PROD_DIR" "$PROD_DIR" nt
    update_config "$PROD_DIR"
    cd $PROD_DIR/lfa
    fw_service_exists
    if [ $? -eq 0 ] ; then
      servEXEs/servMgr -u -n fwLogfile
    fi 
    ./mkserv.bat
    net start fwLogfile
  else
  # scenario 2)
    mkdir_struct "$PROD_DIR"
    copy_files "$PROD_DIR" "$PROD_DIR" aix
    grep local4 /etc/syslog.conf > /etc/fw.conf
    updateConfig.pl $PROD_DIR/lfa/conf/fwLogfile.conf ServerName " $TEC_SERVER"
    updateConfig.pl $PROD_DIR/lfa/conf/fwLogfile.conf PortNo " $TEC_PORT"
    updateConfig.pl $PROD_DIR/install.cfg PERL_LOC " $PERL_LOC"
    updateConfig.pl $PROD_DIR/lfa/conf/fwLogfile.conf EOFfile " $PROD_DIR/lfa/EOFfile.dne"
    ln -f -s $PROD_DIR/lfa /etc/Tivoli/lfa
    cd $PROD_DIR/lfa
    ADAPTER_HOME=`pwd`
    export ADAPTER_HOME
    $PERL_LOC ./fwLogfile.pl
    if [ $? -eq 0 ] ; then
      echo "Logfile adapter started!"
      # add to /etc/rc.nfs if it doesn't already exist
      grep fwLogfile /etc/rc.nfs > /dev/null
      if [ $? -eq 1 ] ; then
        cd $PROD_DIR
        $PERL_LOC ./install.pl -f install.cfg
      else
        echo "/etc/rc.nfs already has the logfile adapter entry!"
      fi
    else
      echo "Logfile adapter did not start!" >&2
    fi 
  fi
else
  if [ x"$ETC" = x"$SystemRoot/system32/drivers/etc/Tivoli" ] ; then
  # scenario 3)
    mkdir_struct "$ETCA"
    copy_files "$LCF_TOOLSDIR" "$ETCA" nt
    update_config "$ETCA"
    cd $ETCA/lfa
    fw_service_exists
    if [ $? -eq 0 ] ; then
      servEXEs/servMgr -u -n fwLogfile
    fi
    ./mkserv.bat
    net start fwLogfile
  else
  # scenario 4)
    mkdir_struct "$ETC"
    copy_files "$LCF_TOOLSDIR" "$ETC" aix
    grep local4 /etc/syslog.conf > /etc/fw.conf 
    updateConfig.pl $ETC/lfa/conf/fwLogfile.conf ServerName " $TEC_SERVER"
    updateConfig.pl $ETC/lfa/conf/fwLogfile.conf PortNo " $TEC_PORT"
    updateConfig.pl $LCF_TOOLSDIR/install.cfg PERL_LOC " $PERL_LOC"
    updateConfig.pl $ETC/lfa/conf/fwLogfile.conf EOFfile " $ETC/lfa/EOFfile.dne"
    cd $ETC/lfa
    ADAPTER_HOME=`pwd`
    export ADAPTER_HOME
    $PERL_LOC ./fwLogfile.pl
    if [ $? -eq 0 ] ; then
      echo "Logfile adapter started!"
      # add to /etc/rc.nfs if it doesn't already exist
      grep fwLogfile /etc/rc.nfs > /dev/null
      if [ $? -eq 1 ] ; then
        cd $LCF_TOOLSDIR
        $PERL_LOC ./install.pl -f install.cfg
      else
        echo "/etc/rc.nfs already has the logfile adapter entry!"
      fi
    else
      echo "Logfile adapter did not start!" >&2
    fi
  fi
fi 
