#!/bin/sh 
# -- BEGIN COPYRIGHT --
# IBM SecureWay Firewall Version 4.2
# Licensed Materials - Property of IBM
#
# 5697-F48
#
# (C) Copyright IBM Corp. 1985, 1994, 1999 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# -- END COPYRIGHT --

#
# Program File: config_tec.sh
#

# attempts to back out the changes made to the event server
backout()
{
  echo "backing out changes"
  for State in $BackoutList ; do
    case "$State" in
      "Rulebase")  
        echo "Error: Deleting $Rulebase rulebase."
        wdelrb $Rulebase
        ;;
      "NewClasses")
        echo "Error: Deleting New Classes."
        wdelrbclass `basename $ClassFile` $Rulebase
        ;;
      "NewRules")
        echo "Error: Deleting New Rules."
        wdelrbrules $RulesFile $Rulebase
        ;;
      "EventGroup")
        echo "Error: Deleting $EventGroupName event group."
        wdeleg $EventSrcName
        ;;
      "AssignConsole")
        echo "Error: Unassigning $EventGroupName from $EventConsole."
        wunassigneg @EnterpriseClient:"$EventConsole" $EventGroupName
        ;;
      "Filters")
        echo "Error: Sorry, unable to delete filters"
        ;;
    esac
  done
  echo "Error: Installation Failed."
  exit 1
}

# checks to make sure the rulebase is not present.
verify_rule_base()
{
  if [ -z "$Rulebase" ] ; then
    echo "Error: A rulebase must be defined!"
    backout
  fi

  if wlsrb | grep "^${Rulebase}$" > /dev/null 2>&1 ; then
    CreateNewRulebase="NO"
  else
    CreateNewRulebase="YES"
  fi
}

# makes sure that the rulebase specified as the rulebase base to
# clone actually exists.
verify_clone_rule_base()
{
  echo "Verifying clone rule base"
  if [ -z "$CloneRulebase" ] ; then
    echo "Error: Clone rulebase must be defined!"
    backout
  fi
  if wlsrb | grep "^${CloneRulebase}$" > /dev/null 2>&1 ; then
    echo "$CloneRulebase exists!"
  else
    echo "Error: $CloneRulebase rulebase must already exist!"
    backout
  fi
  echo "Done."
}

# makes sure the path for the cloned rulebase is creatable or exists
verify_clone_dir_path()
{
  echo "Verifying clone dir path"
  if [ -d "$RulebasePath" ] ; then
    echo "Error: Please enter non-existing directory for the rulebase in the task setup dialog."
    backout  
  fi

  if [ ! -d "$RulebasePath" ] ; then
    if $PARTNER_DIR/mkdir2.sh $RulebasePath ; then
      echo "Created $RulebasePath"
    else
      echo "Error: Cannot create new rulebase path."
      backout
    fi
  fi
  echo "Done."
}

# verifies that the specified event console exists
verify_event_console()
{
  if [ ! -z "$EventConsole" ] ; then
    if wlookup -r EnterpriseClient "$EventConsole"  > /dev/null 2>&1 ; then
      echo "$EventConsole exists!"
    else
      echo "Error: $EventConsole event console does not exist!"
      backout
    fi
  fi
}

# add the sentry baroc files to the list of classes to install.
verify_sentry_classes()
{
  echo "Verifying sentry classes"

  if wlsrbclass $VerificationRulebase | \
	grep "$SentryClassSentinel" > /dev/null 2>&1 ; then
    echo "Sentry classes are ok."
  else
    echo "Sentry classes have not been installed, adding them."
    AdapterClassFileList="$AdapterClassFileList $SentryClassFileList"
  fi
  echo "Done."
}

# compile the rulebase! Name passed in as $1
compile_rule_base()
{
  wcomprules $1 
  return 0 
}

# Does the rulebase compile?
verify_current_rule_base_compiles()
{
  echo "Verifying current rule base compiles"
  if compile_rule_base $VerificationRulebase ; then
    echo "$VerificationRulebase compiles successfully!"
  else
    echo "$VerificationRulebase does not compile!" 
    backout
  fi
  echo "Done."
}

# does the newly-created rule base compile?
verify_new_rule_base_compiles()
{
  echo "Verify new rule base compiles"
  if compile_rule_base $Rulebase ; then
    echo "$Rulebase compiles successfully!"
  else
    echo "Error: $Rulebase does not compile!"
    backout
  fi
  echo "Done."
}

# Make a new rule base. Add it to the backout list, too
create_new_rule_base()
{
  echo "Create new rule base"
  if wcrtrb -d $RulebasePath $Rulebase ; then
    echo "Created $Rulebase rulebase."
    BackoutList="Rulebase $BackoutList"
  else
    echo "Error: Failed to create $Rulebase rulebase."
    backout
  fi
 echo "Done."
}

# clone a given rule base
clone_rule_base()
{
  echo "Clone rule base"
  if wcprb -crf $CloneRulebase $Rulebase ; then
    echo "Copied $CloneRulebase rulebase to $Rulebase."
  else
    echo "Error: Failed to copy $CloneRulebase rulebase to $Rulebase."
    backout
  fi
 echo "Done."
}

# suck new class files into the rulebase if the sentinel class
# isn't present.
import_new_classes()
{
  echo "Import new classes"
  wlsrbclass $Rulebase $AdapterSentinelClass > /dev/null 2>&1

  if [ $? -ne 0 ] ; then
    for ClassFile in $AdapterClassFileList
    do
      if wimprbclass $PARTNER_DIR/$ClassFile $Rulebase > /dev/null 2>&1 ; then
        echo "Imported $ClassFile to $Rulebase rulebase."
        BackoutList="NewClasses $BackoutList"
      else
        echo "Error: Failed to import $ClassFile to $Rulebase rulebase."
        backout
      fi
    done
  else
    echo "$AdapterSentinelClass is preconfigured in $Rulebase rulebase."
  fi
  echo "Done."
}

# import them rules files if they're not in the rule base
import_new_rules()
{
  echo "Import new rules"

  for RulesFile in $RulesFileList
  do
    RulesSet=$RulesFile
    RulesFile=`echo $RulesFile | awk -F/ '{print $NF}'`
    wlsrbrules $Rulebase $RulesFile > /dev/null 2>&1
    if [ $? -ne 0 ] ; then
      if wimprbrules $PARTNER_DIR/$RulesSet $Rulebase  > /dev/null 2>&1 ; then
        echo "Imported $RulesFile to $Rulebase rulebase."
        BackoutList="NewRules $BackoutList"
      else
        echo "Error: Failed to import $RulesFile to $Rulebase rulebase."
        backout
      fi
    else
      echo "$RulesFile is preconfigured in $Rulebase rulebase."
    fi
  done
  echo "Done."
}

# make a new event source. Note that the label option is unused
create_new_event_source()
{
  echo "Create new event source"
  if wcrtsrc -b $TmpBitmap $TmpSource ; then
    echo "Created $TmpSource event source."
    BackoutList="EventSource $BackoutList"
  else
    echo "Failed to create $TmpSource event source."
    backout
  fi
  echo "Done."
}

# create new event source(s)
# $TmpSource = source
# $TmpSource = source bitmap

install_new_event_source()
{
  echo "Install new event source"

  for SourceID in $Sources
  do
    eval TmpSource=$"$SourceID"
    eval TmpBitmap=$"$SourceID"Bitmap

    wlssrc 2> /dev/null | grep "^${TmpSource}" > /dev/null 2>&1
    if [ $? -eq 0 ] ; then
      echo "$TmpSource event source already exists."
      if [ "$DeleteOldEventSource" = "YES" ] ;then
        if wdelsrc $TmpSource; then
          echo "Removed $TmpSource."
        else
          echo "Error: Failed to delete $TmpSource event source."
        backout
        fi
        create_new_event_source
      fi
    else
    create_new_event_source
    fi
  done
  echo "Done."
}

# makes a new event group
create_new_event_group()
{
  echo "Install new event group"
  if wcrteg -b $EventGroupIcon $EventGroupName ; then
    echo "Created $EventGroupName event group."
    BackoutList="EventGroup $BackoutList"
  else
    "Error: Failed to create $EventGroupName event group."
    backout
  fi
  echo "Done."
}

# creates a new event group. Deletes a like-named group if necessary.
# $EventGroupName -> name of the event group
# $DeleteOldMastroEventGroup -> should delete same-named group?

install_new_event_group()
{
  echo "Install new event group"

  if wlseg 2> /dev/null | grep "^${EventGroupName}$" > /dev/null 2>&1 ; then
    echo "$EventGroupName event group already exists."
    if [ "$DeleteOldEventGroup" = "YES" ] ; then
      if wdeleg $EventGroupName ; then
        echo "Removed $EventGroupName."
      else
        echo "Error: Failed to delete $EventGroupName event group."
        backout
      fi
      create_new_event_group
    fi
  else
    create_new_event_group
  fi
  echo "Done."
}

# Does what it says.

assign_event_group_to_console()
{
  echo "Assign event group to console"

  if [ ! -z "$EventConsole" ] ; then
    wlsassigneg @EnterpriseClient:"$EventConsole" | \
	grep "^${EventGroupName}" > /dev/null 2>&1

    if [ $? -eq 0 ] ; then
      echo "$EventGroupName already assigned to $EventConsole."
      BackoutList="AssignConsole $BackoutList"
    else
      if wassigneg @EnterpriseClient:"$EventConsole" $EventGroupName \
		$EventGroupRoles > /dev/null 2>&1 ; then
        echo "Assigned $EventGroupName to $EventConsole."
      else
        echo "Error: Failed to assign $EventGroupName to $EventConsole."
        backout
      fi
    fi
  fi
  echo "Done."
}

# load the rulebase
load_new_rules()
{
  echo "Load new rules"
  if wloadrb $Rulebase ; then
    echo "Loaded $Rulebase rulebase."
    Backoutlist="EventServer $BackoutList"
  else
    echo "Error: Failed to load $Rulebase into EventServer"
    backout
  fi
  echo "Done."
}

restart_event_server()
{
  echo "Restart event server"
  if wstopesvr ; then
    echo "Stopped Event Server."
    sleep 5
    if wstartesvr ; then
      echo "Started Event Server."
    else
      echo "Failed to start Event Server."
    fi
  else
    echo "Error: Failed to Stop Event Server."
  fi
  echo "Done."
}

# add an event filter to the event group
add_filter()
{
  echo "Add filter"

  if waddegflt $1 $2 $3 $4 $EventGroupName
  then
    echo "Added event filter $Filter"
    BackoutList="Filters $BackoutList"
  else
    echo "Error: Failed adding event filter $Filter"
    backout
  fi
  echo "Done."
}

# Installs the filter, making the parameter list as needed
install_new_event_filters()
{
  echo "Install new event filters"

  CurrentFilters=`wlseg -f $EventGroupName 2> /dev/null | sed 's/,//g' | \
    awk '/class:/ { 
        if ($4 != "*") printf("-c %s",$4);
        if ($6 != "*") printf(" -s %s",$6);
        if ($8 != "*") printf(" -o %s",$8);
        if ($10 != "*") printf(" -r %s",$10);
        if ($12 != "*") printf(" -u %s",$12);
        printf("\n");
        }'`
  for Filter in $NewFilters
  do
    eval TmpFilter=$"$Filter"
    ALREADY_GOT_IT=0
    OLDIFS=$IFS
    IFS="
"
    export IFS
    for CurrentFilter in $CurrentFilters
    do
      if [ x"$TmpFilter" = x"$CurrentFilter" ]
      then
        echo "$TmpFilter already exists!"
        ALREADY_GOT_IT=1
        break
      fi
    done
    IFS=$OLDIFS
    export IFS
    if [ $ALREADY_GOT_IT -eq 0 ] ;then
      add_filter "$TmpFilter"
    fi
  done
 echo "Done."
}

main()
{
  # make sure this is the TEC server
  IRO=`wlookup InterRegion`
  IRONAME=`idlattr -t -g $IRO name string`
  IRONAME=`eval echo $IRONAME`
  THIS_HOST_INDEX=`objcall 0.0.0 self | awk -F. '{print \$2}'`
  TEC_SERVER_INDEX=`wlookup -r EventServer "EventServer#$IRONAME" | \
	awk -F. '{print \$2}'`
  
  if [ x"$THIS_HOST_INDEX" = x"$TEC_SERVER_INDEX" ] ; then
    echo "Configuring EventServer..."
    verify_rule_base

    if [ "$CreateNewRulebase" = "YES" ] ; then
      verify_clone_rule_base
      verify_clone_dir_path
      VerificationRulebase=$CloneRulebase
    else
      VerificationRulebase=$Rulebase
    fi

    verify_event_console
    verify_sentry_classes
    verify_current_rule_base_compiles
    if [ "$CreateNewRulebase" = "YES" ] ; then
      create_new_rule_base
      clone_rule_base
      verify_new_rule_base_compiles
    fi
    import_new_classes
    import_new_rules
    verify_new_rule_base_compiles
    install_new_event_source
    install_new_event_group
    install_new_event_filters
    assign_event_group_to_console
    load_new_rules
    
    if [ "$Restart" = "Yes" ] ; then
       restart_event_server
    else
       echo "The TEC server must be restarted for changes to take affect!"
    fi

  else
    echo "This script can only be run on the TEC server!"
  fi
  
}

to_unix()
{
  if [ "$INTERP" = "w32-ix86" ] ; then
    UNIX_PATH=`echo $1 | sed -e 's|\\\\|/|g'`
  else
    UNIX_PATH=`printf "%s\n" "$1" | sed -e 's|\\\\|/|g'`
  fi

  eval $2=$UNIX_PATH
}


###############################################################################
# now the Tivoli setup

if [ x"$OS" = x"Windows_NT" ]; then
  ETC=$SystemRoot/system32/drivers/etc/Tivoli
else
  ETC=/etc/Tivoli
fi
 
if [ ! -f $ETC/setup_env.sh ]; then
  echo "Error: file Tivoli setup script does not exist!"
  exit 1
fi
 
. $ETC/setup_env.sh

OSERV=`objcall 0.0.0 get_oserv`
MNOID=`objcall 0.0.0 get_host_location`
#BINDIR=`objcall $MNOID getattr BINDIR`
#DBDIR=`objcall $MNOID getattr DBDIR`
#PLUS_NETFIN_DIR=`objcall $MNOID getattr PLUS_NETFIN_DIR`

#  If this is NT, then etc is in a different location
if [ x\"$OS\" = x\"Windows_NT\" ] ; then
     TEMP=$DBDIR/tmp
fi

# lets get the paths
INST_DIR=`objcall $OSERV query install_dir`

if [ "$INTERP" = "w32-ix86" ] ; then
  to_unix $INST_DIR INST_DIR
fi

# directory prefix? (product name)
PARTNER=SECUREWAY_FIREWALL

# reset the path 
PATH=${INST_DIR}/generic_unix/TME/PLUS/LINK:${PATH}:/usr/ucb
export PATH

# directory in which the adapter was installed
PARTNER_DIR=$INST_DIR/generic_unix/TME/PLUS/$PARTNER

# $EventGroupName -> name of the event group to create
EventGroupName="FIREWALL_PLUS"

# state of the install
BackoutList=""   # MUST always be NULL

############################
# product-specific options #
############################
# debug messages?
if [ -f $TEMP/${PARTNER}debug ]; then
  Debug="YES"
  set -x
else
  Debug="NO"
fi

# when a duplicate event source is found, should we delete it?
DeleteOldEventSource="NO"
DeleteOldEventGroup="NO"

# roles needed for the event group
EventGroupRoles="senior admin user"  

# filter definitions. filters MUST be defined like this!
# if you want to set it to * just leave the option off
#FilterX="-c class -s source -u sub_source -o origin -r sub_origin"

# list of filters. Enter the real filters after this entry
NewFilters="Filter2 Filter3"

# event filter atomic entries
#Filter1="-s FIREWALL"
Filter2="-c FIREWALL_DM -s SENTRY"
Filter3="-c FIREWALL_ADAPTER -s LOGFILE"
            
# list of sources. Enter the real sources after this entry
Sources="Source1 Source2"

# event source 1 (source field set by event adapter)
Source1="LOGFILE"

# event source 2 (source field set by event adapter)
Source2="SENTRY"

# bitmap for source. Note this is the icon name
# entered in APP_Plus.init, under the EventServer part
Source1Bitmap="TivoliPlus"

# bitmap for source.  note that this is the raw icon name
Source2Bitmap="sentry48"

# bitmap for the event group. Note it should be the same name
# as the one defined in the APP_Plus.init file (look for wputbitmap)
EventGroupIcon="TivoliPlus"

# sentinel class, to see if sentry classes have already been installed.
# this is defined in the baroc file
SentryClassSentinel=FIREWALL_DM

# list of sentry classes to import into the rulebase
SentryClassFileList="SecureWayDM.baroc"
AdapterSentinelClass="FIREWALL_ADAPTER"
AdapterClassFileList="SecureWaytecad.baroc"

# list of rules files to install
RulesFileList="SecureWay.rls"

# sentinel task name, to see if the task file has been installed.
TECTaskSentinel=

# list of baroc files that should be removed if present before
# installation of said same class files
# only used if not creating a new rulebase/group/etc.
REMOVE_BAROC_FILES="$AdapterClassFileList $SentryClassFileList"

##########################################################################
if [ $# -ne 4 ] ; then
  echo "usage: $0 Rulebase CloneRulebase RulebasePath EventConsole"
  echo "run wlsrb to see current rule bases"
  echo ""
  echo "create a rule base (clone) via the gui or"
  echo "	wcrtrb -d nemo:$DBDIR/tec/srmClone srmClone"
  echo ""
  echo "The 'RulebasePath' must not already exist - it will be created"
  echo ""
  echo "The 'EventConsole' must exist - to check:"
  echo " wlookup -r EnterpriseClient \$EventConsoleName"
  exit 1
fi

Rulebase=$1
CloneRulebase=$2
RulebasePath=$3
EventConsole=$4
#Restart=$5
Restart="Yes"

PRODUCT="SECUREWAY"

main

if [ $? -eq 0 ] ; then
  echo "Completed."
fi
