#!/bin/sh 
# -- BEGIN COPYRIGHT --
# IBM SecureWay Firewall Version 4.2
# Licensed Materials - Property of IBM
#
# 5697-F48
#
# (C) Copyright IBM Corp. 1985, 1994, 1999 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# -- END COPYRIGHT --

#
# Component Name: http_proxy.sh
#

PRODUCT=SECUREWAY_FIREWALL

# ----------------------------------------------------------------------
# Discover if we are on an LCF endpoint.
# ----------------------------------------------------------------------
if [ "x$LCF_BINDIR" != "x" ]; then
  EP=TRUE
  if [ "x$OS" = "xWindows_NT" ]; then
    ETC=$SystemRoot/system32/drivers/etc/Tivoli
    NULL=nul
  else
    ETC=/etc/Tivoli
    NULL=/dev/null
  fi
  TEMP=/tmp
else
  EP=FALSE
fi

if [ x"$EP" = x"FALSE" ] ; then
  if [ -f $SystemRoot/system32/drivers/etc/Tivoli/setup_env.sh ] ; then
          . $SystemRoot/system32/drivers/etc/Tivoli/setup_env.sh
	  TEMP=$DBDIR/tmp
  else
          . /etc/Tivoli/setup_env.sh
	  TEMP=/tmp
  fi
  OSERV=`objcall 0.0.0 get_oserv`
  INST_DIR=`objcall $OSERV query install_dir`
  PATH=$INST_DIR/generic_unix/TME/PLUS/SECUREWAY_FIREWALL:$BINDIR/AEF:$PATH
  export PATH
fi

#  Debugging code: by creating a file called /tmp/${PRODUCT}debug in
#     the appropriate TEMP directory, the output of scripts is
#     set to debugging (should appear in stderr for the task)

DEBUGFILE=$TEMP/${PRODUCT}debug

if [ -f $DEBUGFILE ]; then
  set -x
fi

# find out if we're starting or stopping the http proxy server
if [ x"$1" != x ] ; then
  # translate entry to all lowercase so we can
  # see if they've entered start or stop
  ACTION=`echo $1 | tr '[A-Z]' '[a-z]'`
  if [ x"$ACTION" != x"stop" -a x"$ACTION" != x"start" ] ; then
    echo "You need to specify either Start or Stop!"
    echo "Please rerun this task!"
    exit 1
  fi
else
  echo "You need to specify either Start or Stop!"
  echo "Please rerun this task!"
  exit 1
fi

#Must unset CHILD_OF_OSERV or it will end up in the firewall environment
#and could really hose up the CLI calls back to TME
unset CHILD_OF_OSERV


if [ x"$ACTION" = x"start" ] ; then
  case `uname -sr` in

	"AIX"*)
                startsrc -s ibmproxy
                if [ $? -eq 1 ] ; then
                  echo Error in starting IBM Firewall HTTP Proxy Server! >&2
                  exit 1
                fi
		;;

	"Windows_NT 4.0"*)
		net start ibmfw_wte
                if [ $? -ne 0 ] ; then
                  echo Error in starting IBM Firewall HTTP Proxy Server! >&2
                  exit 1
                fi
		;;
  esac
else
  case `uname -sr` in

        "AIX"*)
                stopsrc -s ibmproxy
                if [ $? -eq 0 ] ; then
                  echo Stopped IBM Firewall HTTP Proxy Server!
                  exit 0
                else
                  echo Error in stopping IBM Firewall HTTP Proxy Server! >&2
                  exit 1
                fi 
                ;;

        "Windows_NT 4.0"*)
                net stop ibmfw_wte
                if [ $? -ne 0 ] ; then
                  echo Error in stopping IBM Firewall HTTP Proxy Server! >&2
                  exit 1
                fi
                ;;
  esac
fi

exit 0
