#!/bin/sh
# -- BEGIN COPYRIGHT --
# IBM SecureWay Firewall Version 4.2
# Licensed Materials - Property of IBM
#
# 5697-F59
#
# (C) Copyright IBM Corp. 1985, 1994, 1999 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# -- END COPYRIGHT --

#
# Component Name: Courier script for Firewall Configuration Client
#
# Program: secureway_nt_install_after.sh
#

PRODUCT=SECUREWAY_FIREWALL
APP="Client"

# ----------------------------------------------------------------------
# Define env vars ETC and NULL based if we are running on NT or Unix
# ----------------------------------------------------------------------

#OS_TYPE=`uname -s`; rc=$?

#if [ $rc -eq 0 ]; then
#  if [ $OS_TYPE = "AIX" -o $OS_TYPE = "SunOS" -o $OS_TYPE = "HP-UX" -o \
#	$OS_TYPE = "Linux" ]; then
#    OS="Unix"
#  else
#    OS="Windows_NT"
#  fi
#fi

if [ "x$OS" = "xWindows_NT" ]; then
  PATH=/temp/stage/${APP}:$PATH		# for wintel .exe files
  sysRoot="$SystemRoot"
  SystemRoot=`echo "$sysRoot" | sed -e 's|\\\\|/|g'`
  ETC="$SystemRoot/system32/drivers/etc"
  NULL=nul
else
  ETC=/etc
  NULL=/dev/null
fi

# ----------------------------------------------------------------------
# Determine if we are on an LCF Endpoint
# ----------------------------------------------------------------------
if [ "x$LCF_BINDIR" != "x" ]; then
  ENDPOINT=TRUE
else
  ENDPOINT=FALSE
fi

# ----------------------------------------------------------------------
# Source the file $ETC/Tivoli/setup_env.sh
# ----------------------------------------------------------------------

if [ ! -f "$ETC/Tivoli/setup_env.sh" ]; then
  echo "the Tivoli setup script $ETC/Tivoli/setup_env.sh does not exist."
else
  . "$ETC/Tivoli/setup_env.sh"
fi
 
# ----------------------------------------------------------------------
# Now that we have the Tivoli environment sourced, now we can set some
# other common env. vars.
# ----------------------------------------------------------------------

if [ "x$OS" = "xWindows_NT" ]; then
  TEMP=/temp

  if [ -d "${DBDIR}/tmp" ]; then
    DBTEMP="$DBDIR/tmp"
  else
    DBTEMP=$TEMP
  fi

  PATH=/temp/stage/${APP}:$PATH		# for wintel .exe files
else
  TEMP=/tmp
  DBTEMP=/tmp
fi

# ----------------------------------------------------------------------
#  Debugging code: by creating a file called ${PRODUCT}debug in
#     the appropriate TEMP directory, the output of the script is
#     redirected to a file in TEMP by the same name as the script.
# ----------------------------------------------------------------------
 
if [ -f "${DBTEMP}/${PRODUCT}debug" ]; then
  set -x
  DEBUG=1
  LOGFILE="$DBTEMP/${PRODUCT}_after_${APP}.log"
else
  DEBUG=0
  LOGFILE=$NULL
fi

# ----------------------------------------------------------------------
# Define any local functions here.
# ----------------------------------------------------------------------

# ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
# main()
#
# I'm not using functions because it would give me problems
# gathering up the output.
# ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

(
  # ---------------------------------------------------------
  # source the input values when the config task was executed
  # ---------------------------------------------------------

  . ${TEMP}/stage/${APP}/${APP}.val

  if [ "x$OS" = "xWindows_NT" ]; then

	# ----------------------------------------------------
	# Ok, do an NT install
	# ----------------------------------------------------

    PC_PATH="$STAGE_PATH"; STG_PATH=`echo $PC_PATH | sed -e 's|/|\\\\|g'`

    cp ${APP}.iss $STAGE_PATH/nt40/$LOCALE_SET/Client/setup.iss
    cd $STAGE_PATH/nt40/$LOCALE_SET/Client

    ./setup.exe -s ./setup.iss

	# ----------------------------------------------------
  else	# only for nt
	# ----------------------------------------------------

    echo "This install script will only work on Windows NT."
    exit 1

  fi

  # -----------------------------------------------------
  # Clean up Staging area (as best we can) ...

#  cd "$STAGE_PATH"; cd ..
# rm -rf "${STAGE_PATH}"

#  cd ${TEMP}/stage
#  rm -rf ${APP}

) >$LOGFILE 2>&1
