#!/bin/sh
# -- BEGIN COPYRIGHT --
# IBM SecureWay Firewall Version 4.2
# Licensed Materials - Property of IBM
#
# 5697-F48
#
# (C) Copyright IBM Corp. 1985, 1994, 1999 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# -- END COPYRIGHT --

#
# Program: secureway_unix_ci_config.sh
#
# Description: This script configures a filepack to install the MasterCell
#   Browser onto a Managed Node or LCF EndPoint.
#

PRODUCT=SECUREWAY_FIREWALL
PRODUCT_LABEL="IBM SecureWay Firewall"	# This is the pretty output format

APP="Client"   		     	# One word description
APP_NAME="Configuration Client"	# Multi word description

FILEPACK_LABEL="Install Configuration Clients"

# ----------------------------------------------------------------------
# Define env vars ETC and NULL based if we are running on NT or Unix
# ----------------------------------------------------------------------

OS_TYPE=`uname -s`; rc=$?

if [ $rc -eq 0 ]; then
  if [ $OS_TYPE = "AIX" -o $OS_TYPE = "SunOS" -o $OS_TYPE = "HP-UX" -o \
       $OS_TYPE = "Linux" ]; then
    OS="Unix"
  else
    OS="Windows_NT"
  fi
fi

if [ "x$OS" = "xWindows_NT" ]; then
  ETC=$SystemRoot/system32/drivers/etc/Tivoli
  NULL=nul
else
  ETC=/etc/Tivoli
  NULL=/dev/null
fi

# ----------------------------------------------------------------------
# Source the file $ETC/setup_env.sh
# ----------------------------------------------------------------------

if [ ! -f $ETC/setup_env.sh ]; then
  echo "Error: the Tivoli setup script $ETC/setup_env.sh does not exist!"
  exit 1
else
  . $ETC/setup_env.sh
fi
 
# ----------------------------------------------------------------------
# Now that we have the Tivoli environment sourced, now we can set some
# other common env. vars.
# ----------------------------------------------------------------------

if [ "x$OS" = "xWindows_NT" ]; then
  TEMP=c:/temp
  DBTEMP=$DBDIR/tmp
  PATH=$PATH:$BINDIR/tools		# for sed, grep, ..., on NT
else
  TEMP=/tmp
  DBTEMP=/tmp
  PATH=$PATH:/etc/Tivoli/bin		# for perl
fi

OSERV=`objcall 0.0.0 get_oserv`
INST_DIR=`objcall $OSERV query install_dir`

PRODUCT_DIR=$BINDIR/../generic_unix/TME/PLUS/SECUREWAY_FIREWALL

PATH=$PATH:$PRODUCT_DIR/../LINK
export PATH
MNOID=`objcall 0.0.0 get_host_location`
eval MNNAME=`idlattr -t -g $MNOID label string`

IRO=`wlookup InterRegion`
IRONAME=`idlattr -t -g $IRO name string`
IRONAME=`eval echo $IRONAME`

# ----------------------------------------------------------------------
#  Debugging code: by creating a file called ${PRODUCT}debug in
#     the appropriate TEMP directory, the output of the script is
#     redirected to a file in TEMP by the same name as the script.
# ----------------------------------------------------------------------
 
if [ -f "${DBTEMP}/${PRODUCT}debug" ]; then
  set -x
  DEBUG=1
else
  DEBUG=0
fi

# ----------------------------------------------------------------------
# Define any local functions here.
# ----------------------------------------------------------------------

# ----------------------------------------------------------------------
#  Function: to_unix converts back to forward slashes
# ----------------------------------------------------------------------

to_unix()
{
  if [ "$INTERP" = "w32-ix86" ] ; then
    UNIX_PATH=`echo $1 | sed -e 's|\\\\|/|g'`
  else
    UNIX_PATH=`printf "%s\n" "$1" | sed -e 's|\\\\|/|g'`
  fi

  eval $2=$UNIX_PATH
}

# ----------------------------------------------------------------------
#  Function: to_pc converts forward to back slashes
# ----------------------------------------------------------------------

to_pc()
{
  PC_PATH=`echo $1 | sed -e 's|/|\\\\\\\\|g'`
  eval $2=$PC_PATH
}

# ----------------------------------------------------------------------
# function: checkArgs()
#
# description: determine that the cli values provided are valid
#   SRC_HOST=$1;   shift
#   SRC_PATH=$1;   shift
#   STAGE_PATH=$1; shift
# ----------------------------------------------------------------------

checkArgs()
{
  if [ "x$SRC_HOST" = "x" ]; then
    echo "You must specify the managed node on which the $PRODUCT_LABEL $APP_NAME install files reside." >&2
    exit 1
  fi

  if [ "x$SRC_PATH" = "x" ]; then
    echo "You must specify the directory on the source host where the $PRODUCT_LABEL $APP_NAME install files reside." >&2
    exit 1
  fi

  if [ "x$STAGE_PATH" = "x" ]; then
    echo "You must specify the directory where the $PRODUCT_LABEL $APP_NAME will be staged on the target hosts." >&2
    exit 1
  fi

  if [ "$STAGE_PATH" = "/" ]; then
    echo "Do not stage into the root filesystem. Please provide a directory." >&2
    exit 1
  fi

}

# ------------------------------------------------------------------------
# CreateProfile()
#
# This function is used to create the filepack profile manager
# ------------------------------------------------------------------------

CreateProfile()
{

  if [ $DEBUG -eq 1 ]; then
    set -x
  fi

  POLICY_REGION=SecureWay_FilePacks	# PRNAME
  PROFILE_MANAGER="Firewall Ancillary Filepack"
  PROFILE_NAME=$FP_NAME

#  PROFILE=`wlookup -r FilePackage "$FP_NAME#$IRONAME" 2>$NULL`

  PROFILE=`wlookup -ar FilePackage | grep "$FP_NAME"`

  if [ x"$PROFILE" = x ] ; then
    wcrtprf @ProfileManager:"$PROFILE_MANAGER" FilePackage \
	 "$PROFILE_NAME" > $NULL
  fi

}

# ------------------------------------------------------------------------
# makeNested()
#
# This function is used to create the nested filepack for a given product.
# ------------------------------------------------------------------------

makeNested()
{
  echo "Creating nested install filepack ${PRODUCT_LABEL} ${APP_NAME}"

  if [ $DEBUG -eq 1 ]; then
    set -x
  fi

  NESTED_FP_NAME="${PRODUCT}_${APP}_after_aix"

  NESTED_FP_EXPORT="$TEMP"/${PRODUCT}_${APP}_export_after_aix.fp

  rm -f $NESTED_FP_EXPORT

  if [ ! -f $PRODUCT_DIR/starter_export_aix.fp ]; then
    echo "It does not look like the SecureWay Firewall plus module is installed"
    echo "The files needed to proceed were not found"
    exit 1
  fi

  if [ -f "$DBTEMP/${PRODUCT}debug" ]; then
    LOGHOST=$SRC_HOST
    LOGFILE=$DBTEMP/$NESTED_FILEPACK_NAME.log
  else
    LOGHOST=""
    LOGFILE=""
  fi

  # -------------------------------------------------------------
  # Create child filepack. The filepack simply grabs the after
  # script from the machine that the config task ran on and
  # copies it to the source machine.
  # -------------------------------------------------------------

  cat $PRODUCT_DIR/starter_export_aix.fp > $NESTED_FP_EXPORT

  cat - >> $NESTED_FP_EXPORT <<EOFNFP
log_host=$LOGHOST
log_file=$LOGFILE
src_relpath=
unix_platform_prefix=/tmp/stage/$APP
nt_platform_prefix=/temp/stage/$APP
win_platform_prefix=/temp/stage/$APP
win95_platform_prefix=/temp/stage/$APP
unix_default_dir_uid=$OWNER
unix_default_file_uid=$OWNER
unix_after_prog_path=
nt_after_prog_path=
keep_paths=n
nested_first=n
%
$PRODUCT_DIR/secureway_unix_install_after.sh
$PRODUCT_DIR/${APP}.val
$PRODUCT_DIR/updateConfig.pl
%
%
EOFNFP

  #
  # let's see if the file package exists. If it doesn't, then we create it.
  #

  # wlookup -r FilePackage "$NESTED_FP_NAME" 2>&1 >$NULL
  PACKAGE=`wlookup -ar FilePackage | grep "$NESTED_FP_NAME "`

  if [ x"$PACKAGE" = x ]; then
  # if [ $? -ne 0 ]; then
    FP_NAME=$NESTED_FP_NAME

    CreateProfile
  fi

  if [ ! -f $BINDIR/bin/wimprtfp -a ! -f $BINDIR/bin/wimprtfp.exe ]; then
    echo "It does not appear that Software Distribution is installed on this managed node"
    echo "Please install Software Distribution and try again"

    rm $NESTED_FP_EXPORT

    exit 1
  fi

  wimprtfp -h @ManagedNode:"$MNNAME" \
        @FilePackage:"$NESTED_FP_NAME#$IRONAME" < $NESTED_FP_EXPORT

}

# ----------------------------------------------------------------------
# makeExportaix()
#
# This function is used to create the filepack for a given product.
# ----------------------------------------------------------------------

makeExportaix()
{
  echo "Creating install filepack ${PRODUCT_LABEL} ${APP_NAME}"

  if [ $DEBUG -eq 1 ]; then
    set -x
  fi

  FILEPACK_NAME="${PRODUCT}_${APP}_install_aix"
 
  FILEPACK_EXPORT="$TEMP"/${PRODUCT}_${APP}_export_aix.fp
 
  rm -f $FILEPACK_EXPORT

  if [ ! -f $PRODUCT_DIR/starter_export_aix.fp ]; then
    echo "It does not look like the SecureWay Firewall plus module is installed"
    echo "The files needed to proceed were not found"
    exit 1
  fi
  
  if [ -f "$DBTEMP/${PRODUCT}debug" ]; then
    LOGHOST=$SRC_HOST
    LOGFILE=$DBTEMP/$FILEPACK_NAME_aix.log
  else
    LOGHOST=""
    LOGFILE=""
  fi
  
  # -------------------------------------------------------------
  # Create parent filepack. The nested filepack is used to
  # pick-up the after script from a machine that has the plus
  # module installed. Otherwise, there would be a limitation
  # that the source machine has to have the plus module installed.
  # -------------------------------------------------------------
    
  cat $PRODUCT_DIR/starter_export_aix.fp > $FILEPACK_EXPORT
  
  cat - >> $FILEPACK_EXPORT <<EOF
log_host=$LOGHOST
log_file=$LOGFILE
src_relpath=
unix_platform_prefix=$STAGE_PATH
nt_platform_prefix=$STAGE_PATH
win_platform_prefix=$STAGE_PATH
win95_platform_prefix=$STAGE_PATH
unix_default_dir_uid=$OWNER
unix_default_file_uid=$OWNER
unix_after_prog_path=/tmp/stage/${APP}/secureway_unix_install_after.sh
nt_after_prog_path=/temp/stage/${APP}/after_${APP}.bat
95_after_prog_path=/temp/stage/${APP}/after_${APP}.bat
keep_paths=n
nested_first=y
%
$SRC_PATH/AIX/AIX432/.toc
$SRC_PATH/AIX/AIX432/fw.cfgcli.obj
%
$NESTED_FP_NAME
%
EOF


  #
  # let's see if the file package exists. If it doesn't, then we create it.
  #

  # wlookup -r FilePackage "$FILEPACK_NAME" 2>&1 >$NULL
  PACKAGE=`wlookup -ar FilePackage | grep "$FP_NAME "`

  if [ x"$PACKAGE" = x ]; then
  # if [ $? -ne 0 ]; then
    FP_NAME=$FILEPACK_NAME

    CreateProfile
  fi

  if [ ! -f $BINDIR/bin/wimprtfp -a ! -f $BINDIR/bin/wimprtfp.exe ]; then
    echo "It does not appear that Software Distribution is installed on this machine"
    echo "Please install Software Distribution and try again"
   
    rm $FILEPACK_EXPORT
   
    exit 1
  fi

  wcrtsprf "Install Configuration Clients" FilePackage "SecureWay Configuration Client Install for AIX" "Install Configuration Clients"

  wimprtfp -h @ManagedNode:"$SRC_HOST" \
        @FilePackage:"SecureWay Configuration Client Install for AIX" < $FILEPACK_EXPORT

  if [ $DEBUG -ne 1 ]; then
    rm $FILEPACK_EXPORT
  fi
}

# ----------------------------------------------------------------------
# function: setVal()
#
# description: store the target path, SRC_PATH STAGE_PATH 
# ----------------------------------------------------------------------

setVal()
{
  if [ $DEBUG -eq 1 ]; then
    set -x
  fi
  
  to_unix $SRC_PATH SRC_PATH
  to_unix $STAGE_PATH STAGE_PATH

  echo "SRC_PATH=\"$SRC_PATH\""     >> $PRODUCT_DIR/${APP}.val
  echo "STAGE_PATH=\"$STAGE_PATH\"" >> $PRODUCT_DIR/${APP}.val
  
  $PRODUCT_DIR/updateConfig.pl $PRODUCT_DIR/secureway_unix_install_after.sh STAGE_PATH "$STAGE_PATH"
}

# ----------------------------------------------------------------------
# function: setAttrs()
#
# description: store the target path and owner for when the filepack
#   gets distributed.
# ----------------------------------------------------------------------

setAttrs()
{
  if [ $DEBUG -eq 1 ]; then
    set -x
  fi

  FPoid=`wlookup -r FilePackage "$FILEPACK_NAME"`

  objcall $FPoid addattr targetPath  2>&1 >$NULL
  objcall $FPoid addattr targetOwner 2>&1 >$NULL

  objcall $FPoid setattr targetOwner "$OWNER"
}

# ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
# main()
# ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

if [ $# -ne 3 ]; then
  echo "Usage: $0 srcHost srcDir stageDir"
  exit 1
fi

SRC_HOST=$1;   shift
SRC_PATH=$1;   shift
STAGE_PATH=$1

OWNER=root

to_unix $SRC_PATH   SRC_PATH
to_unix $STAGE_PATH STAGE_PATH
to_unix $INST_DIR   INST_DIR

LINK_TO="File Packages"

checkArgs
makeNested
makeExportaix

setVal

echo "Done."
