#!/bin/sh
# -- BEGIN COPYRIGHT --
# IBM SecureWay Firewall Version 4.2
# Licensed Materials - Property of IBM
#
# 5697-F59
#
# (C) Copyright IBM Corp. 1985, 1994, 1999 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# -- END COPYRIGHT --

#
# Component Name: Configure Windows Configuration Client
#
# Program: secureway_win_ci_config.sh
#

PRODUCT=SECUREWAY_FIREWALL
PRODUCT_LABEL="IBM SecureWay Firewall"	# This is the pretty output format

APP="Client"   		     	# One word description
APP_NAME="Configuration Client"	# Multi word description

FILEPACK_LABEL="Install Configuration Clients"

# ----------------------------------------------------------------------
# Define env vars ETC and NULL based if we are running on NT or Unix
# ----------------------------------------------------------------------

OS_TYPE=`uname -s`; rc=$?

if [ $rc -eq 0 ]; then
  if [ $OS_TYPE = "AIX" -o $OS_TYPE = "SunOS" -o $OS_TYPE = "HP-UX" -o \
       $OS_TYPE = "Linux" ]; then
    OS="Unix"
  else
    OS="Windows_NT"
  fi
fi

if [ "x$OS" = "xWindows_NT" ]; then
  ETC=$SystemRoot/system32/drivers/etc/Tivoli
  NULL=nul
else
  ETC=/etc/Tivoli
  NULL=/dev/null
fi

# ----------------------------------------------------------------------
# Source the file $ETC/setup_env.sh
# ----------------------------------------------------------------------

if [ ! -f $ETC/setup_env.sh ]; then
  echo "Error: the Tivoli setup script $ETC/setup_env.sh does not exist!"
  exit 1
else
  . $ETC/setup_env.sh
fi
 
# ----------------------------------------------------------------------
# Now that we have the Tivoli environment sourced, now we can set some
# other common env. vars.
# ----------------------------------------------------------------------

if [ "x$OS" = "xWindows_NT" ]; then
  TEMP=c:/temp
  DBTEMP=$DBDIR/tmp
  PATH=$PATH:$BINDIR/tools		# for sed, grep, ..., on NT
else
  TEMP=/tmp
  DBTEMP=/tmp
  PATH=$PATH:/etc/Tivoli/bin		# for perl
fi

OSERV=`objcall 0.0.0 get_oserv`
INST_DIR=`objcall $OSERV query install_dir`

PRODUCT_DIR=$BINDIR/../generic_unix/TME/PLUS/SECUREWAY_FIREWALL

PATH=$PATH:$PRODUCT_DIR/../LINK
export PATH
MNOID=`objcall 0.0.0 get_host_location`
eval MNNAME=`idlattr -t -g $MNOID label string`

IRO=`wlookup InterRegion`
IRONAME=`idlattr -t -g $IRO name string`
IRONAME=`eval echo $IRONAME`

# ----------------------------------------------------------------------
#  Debugging code: by creating a file called ${PRODUCT}debug in
#     the appropriate TEMP directory, the output of the script is
#     redirected to a file in TEMP by the same name as the script.
# ----------------------------------------------------------------------
 
if [ -f "${DBTEMP}/${PRODUCT}debug" ]; then
  set -x
  DEBUG=1
else
  DEBUG=0
fi

# ----------------------------------------------------------------------
# Define any local functions here.
# ----------------------------------------------------------------------

# ----------------------------------------------------------------------
#  Function: to_unix converts back to forward slashes
# ----------------------------------------------------------------------

to_unix()
{
  if [ "$INTERP" = "w32-ix86" ] ; then
    UNIX_PATH=`echo $1 | sed -e 's|\\\\|/|g'`
  else
    UNIX_PATH=`printf "%s\n" "$1" | sed -e 's|\\\\|/|g'`
  fi

  eval $2=$UNIX_PATH
}

# ----------------------------------------------------------------------
#  Function: to_pc converts forward to back slashes
# ----------------------------------------------------------------------

to_pc()
{
  PC_PATH=`echo $1 | sed -e 's|/|\\\\\\\\|g'`
  eval $2=$PC_PATH
}

# ----------------------------------------------------------------------
#  Function: to_lower converts all characters to lower case in
#  a particular string
# ----------------------------------------------------------------------

to_lower()
{
  ANSWER=`echo $1 | tr '[A-Z]' '[a-z]'`
  eval $2=$ANSWER
}

# ----------------------------------------------------------------------
# function: checkArgs()
#
# description: determine that the cli values provided are valid
#   SRC_HOST=$1;   shift
#   SRC_PATH=$1;   shift
#   STAGE_PATH=$1; shift
#   DEST_PATH=$1; shift
#   LOCALE_SET=$1; shift
#   REP_UTIL=$1; shift
#   SOCKS_MON=$1; shift
#   CONF_CLIENT=$1; shift
#   REBOOT=$1
# ----------------------------------------------------------------------

checkArgs()
{
  if [ "x$SRC_HOST" = "x" ]; then
    echo "You must specify the managed node on which the $PRODUCT_LABEL $APP_NAME install files reside." >&2
    exit 1
  fi

  if [ "x$SRC_PATH" = "x" ]; then
    echo "You must specify the directory on the source host where the $PRODUCT_LABEL $APP_NAME install files reside." >&2
    exit 1
  fi

  if [ "x$DEST_PATH" = "x" ]; then
    echo "You must specify the directory where the $PRODUCT_LABEL $APP_NAME will be installed." >&2
    exit 1
  fi

  if [ "x$STAGE_PATH" = "x" ]; then
    echo "You must specify the directory where the $PRODUCT_LABEL $APP_NAME will be staged on the target hosts." >&2
    exit 1
  fi

  if [ "$STAGE_PATH" = "/" ]; then
    echo "Do not stage into the root filesystem. Please provide a directory." >&2
    exit 1
  fi

  if [ "$DEST_PATH" = "/" ]; then
    echo "Do not install into the root filesystem. Please provide a directory." >&2
    exit 1
  fi

  if [ "x$LOCALE_SET" = "x" ]; then
    echo "You must specify the locale which the filepack definition will be taken from.  For example, en_US would be used if you are in the United States." >&2
    exit 1
  fi

  CT=1

# 12/10/1999 -- it seems that the report utilities are required
# no matter what, so we take them out of here and as a prompt
# in the dsl for now, maybe unmark at a later date if we figure
# out how to accomplish
#  if [ x"$REP_UTIL" != x"yes" -a x"$REP_UTIL" != x"no" ] ; then
#    echo "You must specify either Yes or No to indicate whether or not you want to install the Report Utilities." >&2
#    exit 1
#  fi

#  if [ "$REP_UTIL" = "yes" ] ; then
#    CT=`expr $CT + 1`
#  fi

  if [ x"$SOCKS_MON" != x"yes" -a x"$SOCKS_MON" != x"no" ] ; then
    echo "You must specify either Yes or No to indicate whether or not you want to install the Socks Monitor." >&2
    exit 1
  fi

  if [ "$SOCKS_MON" = "yes" ] ; then
    CT=`expr $CT + 1`
  fi

  if [ x"$CONF_CLIENT" != x"yes" -a x"$CONF_CLIENT" != x"no" ] ; then
    echo "You must specify either Yes or No to indicate whether or not you want to install the Configuration Client." >&2
    exit 1
  fi

  if [ "$CONF_CLIENT" = "yes" ] ; then
    CT=`expr $CT + 1`
  fi

  if [ x"$CONF_CLIENT" = x"no" -a x"$SOCKS_MON" = x"no" ] ; then
    echo "You must specify at least one product to install (either or both"
    echo "the Configuration Client and/or the Socks Monitor)!"
    exit 1
  fi
 
# 12/10/99:  report utilities by themselves can be installed, and
# since we're doing it no matter what, we don't need this check
# anymore; see previous comment above if this ever changes, and
# uncomment the code
# 
#  if [ $CT -eq 0 ] ; then
#    echo "You must specify at least one application to be installed." >&2
#    exit 1
#  fi

  if [ x"$REBOOT" != x"yes" -a x"$REBOOT" != x"no" ] ; then
    echo "You must specify either Yes or No to indicate whether or not you want to reboot the machine that you are installing the Configuration Client onto." >&2
    exit 1
  fi

  if [ x"$SOURCE_PLATFORM" != x"aix" -a x"$SOURCE_PLATFORM" != x"nt" ] ; then
    echo "You must specify either aix or nt to indicate what the platform"
    echo "of the source media is."
    exit 1
  fi

}

# ------------------------------------------------------------------------
# CreateProfile()
#
# This function is used to create the filepack profile manager
# ------------------------------------------------------------------------

CreateProfile()
{

  if [ $DEBUG -eq 1 ]; then
    set -x
  fi

  POLICY_REGION=SecureWay_FilePacks	# PRNAME
  PROFILE_MANAGER="Firewall Ancillary Filepack"
  PROFILE_NAME=$FP_NAME

  # PROFILE=`wlookup -r FilePackage "$FP_NAME#$IRONAME" 1>$NULL 2>$NULL`
  
  PROFILE=`wlookup -ar FilePackage | grep "$FP_NAME "`

  if [ x"$PROFILE" = x ] ; then
  #if [ $? -eq 1 ] ; then
    wcrtprf @ProfileManager:"$PROFILE_MANAGER" FilePackage \
	 "$PROFILE_NAME" > $NULL
  fi

}

# ------------------------------------------------------------------------
# makeNested()
#
# This function is used to create the nested filepack for a given product.
# ------------------------------------------------------------------------

makeNested()
{
  echo "Creating nested install filepack ${PRODUCT_LABEL} ${APP_NAME}"

  if [ $DEBUG -eq 1 ]; then
    set -x
  fi

  NESTED_FP_NAME="${PRODUCT}_${APP}_after"

  NESTED_FP_EXPORT="$TEMP"/${PRODUCT}_${APP}_export_after.fp

  rm -f $NESTED_FP_EXPORT

  if [ ! -f $PRODUCT_DIR/starter_export.fp ]; then
    echo "It does not look like the SecureWay Firewall plus module is installed"
    echo "The files needed to proceed were not found"
    exit 1
  fi

  if [ -f "$DBTEMP/${PRODUCT}debug" ]; then
    LOGHOST=$SRC_HOST
    LOGFILE=$DBTEMP/$NESTED_FILEPACK_NAME.log
  else
    LOGHOST=""
    LOGFILE=""
  fi

  # -------------------------------------------------------------
  # Create child filepack. The filepack simply grabs the after
  # script from the machine that the config task ran on and
  # copies it to the source machine.
  # -------------------------------------------------------------

  cat $PRODUCT_DIR/starter_export.fp > $NESTED_FP_EXPORT

  cat - >> $NESTED_FP_EXPORT <<EOFNFP
log_host=$LOGHOST
log_file=$LOGFILE
src_relpath=
unix_platform_prefix=/tmp/stage/$APP
nt_platform_prefix=/temp/stage/$APP
win_platform_prefix=/temp/stage/$APP
win95_platform_prefix=/temp/stage/$APP
unix_default_dir_uid=$OWNER
unix_default_file_uid=$OWNER
unix_after_prog_path=
nt_after_prog_path=
keep_paths=n
nested_first=n
%
$PRODUCT_DIR/secureway_nt_install_after.sh
$PRODUCT_DIR/after_${APP}.bat
$PRODUCT_DIR/Client.iss
$PRODUCT_DIR/${APP}.val
$PRODUCT_DIR/updateConfig.pl
$INST_DIR/lcf_bundle/bin/w32-ix86/tools/bash.exe
$INST_DIR/lcf_bundle/bin/w32-ix86/tools/perl.exe
$INST_DIR/lcf_bundle/bin/w32-ix86/tools/sed.exe
$INST_DIR/lcf_bundle/bin/w32-ix86/tools/cp.exe
$INST_DIR/lcf_bundle/bin/w32-ix86/tools/rm.exe
$INST_DIR/lcf_bundle/bin/w32-ix86/tools/win32gnu.dll
%
%
EOFNFP

  #
  # let's see if the file package exists. If it doesn't, then we create it.
  #

  # wlookup -r FilePackage "$NESTED_FP_NAME" 2>&1 >$NULL
  PACKAGE=`wlookup -ar FilePackage | grep "$NESTED_FP_NAME "`

  if [ x"$PACKAGE" = x ]; then
    FP_NAME=$NESTED_FP_NAME
    CreateProfile
  fi

  if [ ! -f $BINDIR/bin/wimprtfp -a ! -f $BINDIR/bin/wimprtfp.exe ]; then
    echo "It does not appear that Software Distribution is installed on this managed node"
    echo "Please install Software Distribution and try again"

    rm $NESTED_FP_EXPORT

    exit 1
  fi

  wimprtfp -h @ManagedNode:"$MNNAME" \
        @FilePackage:"$NESTED_FP_NAME#$IRONAME" < $NESTED_FP_EXPORT

}

# ----------------------------------------------------------------------
# makeExport()
#
# This function is used to create the filepack for a given product.
# ----------------------------------------------------------------------

makeExport()
{
  echo "Creating install filepack ${PRODUCT_LABEL} ${APP_NAME}"

  if [ $DEBUG -eq 1 ]; then
    set -x
  fi

  FILEPACK_NAME="${PRODUCT}_${APP}_install"

  FILEPACK_EXPORT="$TEMP"/${PRODUCT}_${APP}_export.fp

  rm -f $FILEPACK_EXPORT

  if [ ! -f $PRODUCT_DIR/starter_export.fp ]; then
    echo "It does not look like the SecureWay Firewall plus module is installed"
    echo "The files needed to proceed were not found"
    exit 1
  fi

  if [ -f "$DBTEMP/${PRODUCT}debug" ]; then
    LOGHOST=$SRC_HOST
    LOGFILE=$DBTEMP/$FILEPACK_NAME.log
  else
    LOGHOST=""
    LOGFILE=""
  fi

  # -------------------------------------------------------------
  # Create parent filepack. The nested filepack is used to
  # pick-up the after script from a machine that has the plus
  # module installed. Otherwise, there would be a limitation
  # that the source machine has to have the plus module installed.
  # -------------------------------------------------------------

  cat $PRODUCT_DIR/starter_export.fp > $FILEPACK_EXPORT

  cat - >> $FILEPACK_EXPORT <<EOF
log_host=$LOGHOST
log_file=$LOGFILE
src_relpath=
unix_platform_prefix=$STAGE_PATH
nt_platform_prefix=$STAGE_PATH
win_platform_prefix=$STAGE_PATH
win95_platform_prefix=$STAGE_PATH
unix_default_dir_uid=$OWNER
unix_default_file_uid=$OWNER
unix_after_prog_path=/tmp/stage/${APP}/after_${APP}.sh
nt_after_prog_path=/temp/stage/${APP}/after_${APP}.bat
95_after_prog_path=/temp/stage/${APP}/after_${APP}.bat
keep_paths=y
nested_first=y
%
$SRC_PATH/books/$LOCALE_SET/bannerx.gif
$SRC_PATH/books/$LOCALE_SET/fwinstal.html
$SRC_PATH/books/$LOCALE_SET/fwinstal.pdf
$SRC_PATH/books/$LOCALE_SET/fwredbk.pdf
$SRC_PATH/books/$LOCALE_SET/fwref.pdf
$SRC_PATH/books/$LOCALE_SET/fwuser.pdf
$SRC_PATH/nt40/IBMFWWTE/DATA.TAG
$SRC_PATH/nt40/IBMFWWTE/DATA1.CAB
$SRC_PATH/nt40/IBMFWWTE/LANG.DAT
$SRC_PATH/nt40/IBMFWWTE/LAYOUT.BIN
$SRC_PATH/nt40/IBMFWWTE/OS.DAT
$SRC_PATH/nt40/IBMFWWTE/SERVICE.TXT
$SRC_PATH/nt40/IBMFWWTE/SETUP.BMP
$SRC_PATH/nt40/IBMFWWTE/SETUP.EXE
$SRC_PATH/nt40/IBMFWWTE/SETUP.INI
$SRC_PATH/nt40/IBMFWWTE/SETUP.INS
$SRC_PATH/nt40/IBMFWWTE/SETUP.ISS
$SRC_PATH/nt40/IBMFWWTE/SETUP.LID
$SRC_PATH/nt40/IBMFWWTE/WTELEVEL
$SRC_PATH/nt40/IBMFWWTE/_INST32I.EX_
$SRC_PATH/nt40/IBMFWWTE/_ISDEL.EXE
$SRC_PATH/nt40/IBMFWWTE/_SETUP.DLL
$SRC_PATH/nt40/IBMFWWTE/_SYS1.CAB
$SRC_PATH/nt40/IBMFWWTE/_USER1.CAB
$SRC_PATH/nt40/LAP/JRE_WIN/CHANGES
$SRC_PATH/nt40/LAP/JRE_WIN/LICENSE.IBM
$SRC_PATH/nt40/LAP/JRE_WIN/README
$SRC_PATH/nt40/LAP/JRE_WIN/fixes.lst
$SRC_PATH/nt40/LAP/JRE_WIN/readme.ibm
$SRC_PATH/nt40/LAP/JRE_WIN/bin/JdbcOdbc.dll
$SRC_PATH/nt40/LAP/JRE_WIN/bin/javai.dll
$SRC_PATH/nt40/LAP/JRE_WIN/bin/javakey.exe
$SRC_PATH/nt40/LAP/JRE_WIN/bin/jpeg.dll
$SRC_PATH/nt40/LAP/JRE_WIN/bin/jre.exe
$SRC_PATH/nt40/LAP/JRE_WIN/bin/jrew.exe
$SRC_PATH/nt40/LAP/JRE_WIN/bin/math.dll
$SRC_PATH/nt40/LAP/JRE_WIN/bin/mmedia.dll
$SRC_PATH/nt40/LAP/JRE_WIN/bin/net.dll
$SRC_PATH/nt40/LAP/JRE_WIN/bin/rmiregistry.exe
$SRC_PATH/nt40/LAP/JRE_WIN/bin/symcjit.dll
$SRC_PATH/nt40/LAP/JRE_WIN/bin/sysresource.dll
$SRC_PATH/nt40/LAP/JRE_WIN/bin/winawt.dll
$SRC_PATH/nt40/LAP/JRE_WIN/bin/zip.dll
$SRC_PATH/nt40/LAP/JRE_WIN/lib/DeIsL1.isu
$SRC_PATH/nt40/LAP/JRE_WIN/lib/DeIsL2.isu
$SRC_PATH/nt40/LAP/JRE_WIN/lib/awt.properties
$SRC_PATH/nt40/LAP/JRE_WIN/lib/content-types.properties
$SRC_PATH/nt40/LAP/JRE_WIN/lib/font.properties
$SRC_PATH/nt40/LAP/JRE_WIN/lib/font.properties.ar
$SRC_PATH/nt40/LAP/JRE_WIN/lib/font.properties.iw
$SRC_PATH/nt40/LAP/JRE_WIN/lib/font.properties.ja
$SRC_PATH/nt40/LAP/JRE_WIN/lib/font.properties.ko
$SRC_PATH/nt40/LAP/JRE_WIN/lib/font.properties.ru
$SRC_PATH/nt40/LAP/JRE_WIN/lib/font.properties.th
$SRC_PATH/nt40/LAP/JRE_WIN/lib/font.properties.zh
$SRC_PATH/nt40/LAP/JRE_WIN/lib/font.properties.zh_TW
$SRC_PATH/nt40/LAP/JRE_WIN/lib/i18n.jar
$SRC_PATH/nt40/LAP/JRE_WIN/lib/rt.jar
$SRC_PATH/nt40/LAP/JRE_WIN/lib/serialver.properties
$SRC_PATH/nt40/LAP/JRE_WIN/lib/security/java.security
$SRC_PATH/nt40/LAP/LAP_HOME/lap.jar
$SRC_PATH/nt40/LAP/LA_Home/LA_da
$SRC_PATH/nt40/LAP/LA_Home/LA_de
$SRC_PATH/nt40/LAP/LA_Home/LA_en
$SRC_PATH/nt40/LAP/LA_Home/LA_es
$SRC_PATH/nt40/LAP/LA_Home/LA_fi
$SRC_PATH/nt40/LAP/LA_Home/LA_fr
$SRC_PATH/nt40/LAP/LA_Home/LA_it
$SRC_PATH/nt40/LAP/LA_Home/LA_ja
$SRC_PATH/nt40/LAP/LA_Home/LA_ko
$SRC_PATH/nt40/LAP/LA_Home/LA_nl
$SRC_PATH/nt40/LAP/LA_Home/LA_no
$SRC_PATH/nt40/LAP/LA_Home/LA_pt
$SRC_PATH/nt40/LAP/LA_Home/LA_ru
$SRC_PATH/nt40/LAP/LA_Home/LA_sv
$SRC_PATH/nt40/LAP/LA_Home/LA_zh
$SRC_PATH/nt40/LAP/LA_Home/LA_zh_CN
$SRC_PATH/nt40/LAP/LA_Home/LI_da
$SRC_PATH/nt40/LAP/LA_Home/LI_de
$SRC_PATH/nt40/LAP/LA_Home/LI_en
$SRC_PATH/nt40/LAP/LA_Home/LI_es
$SRC_PATH/nt40/LAP/LA_Home/LI_fi
$SRC_PATH/nt40/LAP/LA_Home/LI_fr
$SRC_PATH/nt40/LAP/LA_Home/LI_it
$SRC_PATH/nt40/LAP/LA_Home/LI_ja
$SRC_PATH/nt40/LAP/LA_Home/LI_ko
$SRC_PATH/nt40/LAP/LA_Home/LI_nl
$SRC_PATH/nt40/LAP/LA_Home/LI_no
$SRC_PATH/nt40/LAP/LA_Home/LI_pt
$SRC_PATH/nt40/LAP/LA_Home/LI_ru
$SRC_PATH/nt40/LAP/LA_Home/LI_sv
$SRC_PATH/nt40/LAP/LA_Home/LI_zh
$SRC_PATH/nt40/LAP/LA_Home/LI_zh_CN
$SRC_PATH/nt40/LAP/LA_Home/icon.gif
$SRC_PATH/nt40/LAP/LA_Home/logo.gif
$SRC_PATH/nt40/LAP/LA_Home/url.properties
$SRC_PATH/nt40/data/client.z
$SRC_PATH/nt40/data/fwhscnt.cfg
$SRC_PATH/nt40/data/fwrules.cfg
$SRC_PATH/nt40/data/fwservices.cfg
$SRC_PATH/nt40/data/krsp1.iss
$SRC_PATH/nt40/data/krsp2.iss
$SRC_PATH/nt40/data/policy1.iss
$SRC_PATH/nt40/data/policy2.iss
$SRC_PATH/nt40/data/policy3.iss
$SRC_PATH/nt40/data/toolkit.iss
$SRC_PATH/nt40/data/toolkit2.iss
$SRC_PATH/nt40/data/tunioctl.dll
$SRC_PATH/nt40/$LOCALE_SET/DATA.TAG
$SRC_PATH/nt40/$LOCALE_SET/NTreadme.html
$SRC_PATH/nt40/$LOCALE_SET/OEMSETUP.INF
$SRC_PATH/nt40/$LOCALE_SET/OPTIONS.INF
$SRC_PATH/nt40/$LOCALE_SET/SETUP.EXE
$SRC_PATH/nt40/$LOCALE_SET/SETUP.INI
$SRC_PATH/nt40/$LOCALE_SET/WEJCFG.HLP
$SRC_PATH/nt40/$LOCALE_SET/_INST32I.EX_
$SRC_PATH/nt40/$LOCALE_SET/_ISDEL.EXE
$SRC_PATH/nt40/$LOCALE_SET/_SETUP.DLL
$SRC_PATH/nt40/$LOCALE_SET/_sys1.cab
$SRC_PATH/nt40/$LOCALE_SET/_user1.cab
$SRC_PATH/nt40/$LOCALE_SET/bbrd1.bmp
$SRC_PATH/nt40/$LOCALE_SET/data1.cab
$SRC_PATH/nt40/$LOCALE_SET/fwrouctr.h
$SRC_PATH/nt40/$LOCALE_SET/fwwctlex.ini
$SRC_PATH/nt40/$LOCALE_SET/fwwctlex.sys
$SRC_PATH/nt40/$LOCALE_SET/ibmisd.txt
$SRC_PATH/nt40/$LOCALE_SET/ibmisdu.txt
$SRC_PATH/nt40/$LOCALE_SET/lang.dat
$SRC_PATH/nt40/$LOCALE_SET/layout.bin
$SRC_PATH/nt40/$LOCALE_SET/os.dat
$SRC_PATH/nt40/$LOCALE_SET/setup.bmp
$SRC_PATH/nt40/$LOCALE_SET/setup.ins
$SRC_PATH/nt40/$LOCALE_SET/setup.lid
$SRC_PATH/nt40/$LOCALE_SET/wej43.sys
$SRC_PATH/nt40/$LOCALE_SET/wejcfg.dll
$SRC_PATH/nt40/$LOCALE_SET/wejcfgex.exe
$SRC_PATH/nt40/$LOCALE_SET/wejdll.sys
$SRC_PATH/nt40/$LOCALE_SET/wejdllpc.h
$SRC_PATH/nt40/$LOCALE_SET/wejpctrs.h
$SRC_PATH/nt40/$LOCALE_SET/wejpctrs.ini
$SRC_PATH/nt40/$LOCALE_SET/wejperf.dll
$SRC_PATH/nt40/$LOCALE_SET/wejtrcol.exe
$SRC_PATH/nt40/$LOCALE_SET/Client/SETUP.INS
$SRC_PATH/nt40/$LOCALE_SET/Client/_INST32I.EX_
$SRC_PATH/nt40/$LOCALE_SET/Client/_ISDEL.EXE
$SRC_PATH/nt40/$LOCALE_SET/Client/_setup.dll
$SRC_PATH/nt40/$LOCALE_SET/Client/_setup.lib
$SRC_PATH/nt40/$LOCALE_SET/Client/setup.bmp
$SRC_PATH/nt40/$LOCALE_SET/Client/setup.exe
$SRC_PATH/nt40/$LOCALE_SET/Client/setup.ini
$SRC_PATH/nt40/$LOCALE_SET/Client/setup.pkg
$SRC_PATH/nt40/$LOCALE_SET/Client/uninst.exe
%
$NESTED_FP_NAME
%
EOF

  #
  # let's see if the file package exists. If it doesn't, then we create it.
  #

  # wlookup -r FilePackage "$FILEPACK_NAME" 2>&1 >$NULL
  PACKAGE=`wlookup -ar FilePackage | grep "$FP_NAME "`

  if [ x"$PACKAGE" = x ]; then
  # if [ $? -ne 0 ]; then
  
    FP_NAME=$FILEPACK_NAME

    CreateProfile
  fi

  if [ ! -f $BINDIR/bin/wimprtfp -a ! -f $BINDIR/bin/wimprtfp.exe ]; then
    echo "It does not appear that Software Distribution is installed on this managed node"
    echo "Please install Software Distribution and try again"

    rm $FILEPACK_EXPORT

    exit 1
  fi

  wcrtsprf "Install Configuration Clients" FilePackage "SecureWay Configuration Client Install for Wintel" "Install Configuration Clients"

  wimprtfp -h @ManagedNode:"$SRC_HOST" \
        @FilePackage:"SecureWay Configuration Client Install for Wintel" < $FILEPACK_EXPORT

  if [ $DEBUG -ne 1 ]; then
    rm $FILEPACK_EXPORT
  fi
}


# ----------------------------------------------------------------------
# makeExportaix()
#
# This function is used to create the filepack for a given product.
# in this case, we're making the filepack for the nt client that
# comes with the aix distribution of the software, which is a bit
# different than the nt one (a few different docs to install,
# darnit)
# ----------------------------------------------------------------------

makeExportaix()
{
  echo "Creating install filepack ${PRODUCT_LABEL} ${APP_NAME}"

  if [ $DEBUG -eq 1 ]; then
    set -x
  fi

  FILEPACK_NAME="${PRODUCT}_${APP}_install"
 
  FILEPACK_EXPORT="$TEMP"/${PRODUCT}_${APP}_export.fp
 
  rm -f $FILEPACK_EXPORT

  if [ ! -f $PRODUCT_DIR/starter_export.fp ]; then
    echo "It does not look like the SecureWay Firewall plus module is installed"
    echo "The files needed to proceed were not found"
    exit 1
  fi
  
  if [ -f "$DBTEMP/${PRODUCT}debug" ]; then
    LOGHOST=$SRC_HOST
    LOGFILE=$DBTEMP/$FILEPACK_NAME.log
  else
    LOGHOST=""
    LOGFILE=""
  fi
  
  # -------------------------------------------------------------
  # Create parent filepack. The nested filepack is used to
  # pick-up the after script from a machine that has the plus
  # module installed. Otherwise, there would be a limitation
  # that the source machine has to have the plus module installed.
  # -------------------------------------------------------------
    
  cat $PRODUCT_DIR/starter_export.fp > $FILEPACK_EXPORT
  
  cat - >> $FILEPACK_EXPORT <<EOF
log_host=$LOGHOST
log_file=$LOGFILE
src_relpath=
unix_platform_prefix=$STAGE_PATH
nt_platform_prefix=$STAGE_PATH
win_platform_prefix=$STAGE_PATH
win95_platform_prefix=$STAGE_PATH
unix_default_dir_uid=$OWNER
unix_default_file_uid=$OWNER
unix_after_prog_path=/tmp/stage/${APP}/after_${APP}.sh
nt_after_prog_path=/temp/stage/${APP}/after_${APP}.bat
95_after_prog_path=/temp/stage/${APP}/after_${APP}.bat
keep_paths=y
nested_first=y
%
$SRC_PATH/books/$LOCALE_SET/AIXreadme.html
$SRC_PATH/books/$LOCALE_SET/bannerx.gif
$SRC_PATH/books/$LOCALE_SET/fwinstal.html
$SRC_PATH/books/$LOCALE_SET/fwinstal.pdf
$SRC_PATH/books/$LOCALE_SET/fwvpnrbk.pdf
$SRC_PATH/books/$LOCALE_SET/fwref.pdf
$SRC_PATH/books/$LOCALE_SET/fwuser.pdf
$SRC_PATH/nt40/data/client.z   
$SRC_PATH/nt40/$LOCALE_SET/Client/SETUP.INS
$SRC_PATH/nt40/$LOCALE_SET/Client/_INST32I.EX_
$SRC_PATH/nt40/$LOCALE_SET/Client/_ISDEL.EXE
$SRC_PATH/nt40/$LOCALE_SET/Client/_setup.dll
$SRC_PATH/nt40/$LOCALE_SET/Client/_setup.lib
$SRC_PATH/nt40/$LOCALE_SET/Client/setup.bmp
$SRC_PATH/nt40/$LOCALE_SET/Client/setup.exe
$SRC_PATH/nt40/$LOCALE_SET/Client/setup.ini
$SRC_PATH/nt40/$LOCALE_SET/Client/setup.pkg
$SRC_PATH/nt40/$LOCALE_SET/Client/uninst.exe
%
$NESTED_FP_NAME
%
EOF


  #
  # let's see if the file package exists. If it doesn't, then we create it.
  #

  # wlookup -r FilePackage "$FILEPACK_NAME" 2>&1 >$NULL
  PACKAGE=`wlookup -ar FilePackage | grep "$FP_NAME "`

  if [ x"$PACKAGE" = x ]; then
  # if [ $? -ne 0 ]; then
    FP_NAME=$FILEPACK_NAME

    CreateProfile
  fi

  if [ ! -f $BINDIR/bin/wimprtfp -a ! -f $BINDIR/bin/wimprtfp.exe ]; then
    echo "It does not appear that Software Distribution is installed on this machine"
    echo "Please install Software Distribution and try again"
   
    rm $FILEPACK_EXPORT
   
    exit 1
  fi

  wcrtsprf "Install Configuration Clients" FilePackage "SecureWay Configuration Client Install for Wintel" "Install Configuration Clients"

  wimprtfp -h @ManagedNode:"$SRC_HOST" \
        @FilePackage:"SecureWay Configuration Client Install for Wintel" < $FILEPACK_EXPORT

  if [ $DEBUG -ne 1 ]; then
    rm $FILEPACK_EXPORT
  fi
}

# ----------------------------------------------------------------------
# function: updateISSfile()
#
# description: make changes to ISS file
# ----------------------------------------------------------------------

updateISSfile()
{
  if [ $DEBUG -eq 1 ]; then
    set -x
  fi

#
# put in some code to support multiple instances of
# running this script; we want to deal with a fresh
# copy of the .iss file each time if at all possible
#
  if [ -f $PRODUCT_DIR/${APP}.iss.old ] ; then
    mv $PRODUCT_DIR/${APP}.iss $PRODUCT_DIR/${APP}.iss.modified
    cp $PRODUCT_DIR/${APP}.iss.old $PRODUCT_DIR/${APP}.iss
  fi
 
  cp $PRODUCT_DIR/${APP}.iss $PRODUCT_DIR/${APP}.iss.old

  if [ $REBOOT = yes ]; then
    perl $PRODUCT_DIR/updateConfig.pl $PRODUCT_DIR/${APP}.iss BootOption 3
  else
    perl $PRODUCT_DIR/updateConfig.pl $PRODUCT_DIR/${APP}.iss BootOption 0
  fi

  PC_PATH=$DEST_PATH; DEST_PATH=`echo $PC_PATH | sed -e 's|/|\\\\|g'`

# to_pc $DEST_PATH DEST_PATH
  perl $PRODUCT_DIR/updateConfig.pl $PRODUCT_DIR/${APP}.iss szDir "$DEST_PATH"
  perl $PRODUCT_DIR/updateConfig.pl $PRODUCT_DIR/${APP}.iss Component-count "$CT"
#  if [ $REP_UTIL = no ]; then
    if [ $SOCKS_MON = no ]; then
      perl $PRODUCT_DIR/updateConfig.pl $PRODUCT_DIR/${APP}.iss Component-1 "Firewall Remote Configuration Client"
      sed "/Component-2/d" $PRODUCT_DIR/${APP}.iss > $PRODUCT_DIR/${APP}.temp
      #sed "/Component-1/d" $PRODUCT_DIR/${APP}.temp > $PRODUCT_DIR/${APP}.temp2
      mv -f $PRODUCT_DIR/${APP}.iss $PRODUCT_DIR/${APP}.iss.bak
      mv -f $PRODUCT_DIR/${APP}.temp $PRODUCT_DIR/${APP}.iss
      #rm -f $PRODUCT_DIR/${APP}.temp
    fi

#    else
#      perl $PRODUCT_DIR/updateConfig.pl $PRODUCT_DIR/${APP}.iss Component-0 "Socks Monitor"
#      perl $PRODUCT_DIR/updateConfig.pl $PRODUCT_DIR/${APP}.iss Component-1 "Firewall Remote Configuration Client"
#      sed "/Component-2/d" $PRODUCT_DIR/${APP}.iss > $PRODUCT_DIR/${APP}.temp
#      mv -f $PRODUCT_DIR/${APP}.iss $PRODUCT_DIR/${APP}.iss.bak
#      mv -f $PRODUCT_DIR/${APP}.temp $PRODUCT_DIR/${APP}.iss
#    fi
#  fi

  if [ $CONF_CLIENT = no ]; then
    sed "/Component-2/d" $PRODUCT_DIR/${APP}.iss > $PRODUCT_DIR/${APP}.temp
    mv -f $PRODUCT_DIR/${APP}.iss $PRODUCT_DIR/${APP}.iss.bak
    mv -f $PRODUCT_DIR/${APP}.temp $PRODUCT_DIR/${APP}.iss
  fi

}

# ----------------------------------------------------------------------
# function: setVal()
#
# description: store the target path, use_MCELL, JRE_PATH
# ----------------------------------------------------------------------

setVal()
{
  if [ $DEBUG -eq 1 ]; then
    set -x
  fi

  #destPath="$DEST_PATH"
  #DEST_PATH=`printf "%s\n" "$destPath" | sed -e 's|\\\\|/|g'`

#  stagePath="$STAGE_PATH"
#  STAGE_PATH=`printf "%s\n" "$stagePath" | sed -e 's|\\\\|/|g'`

  to_unix $DEST_PATH  DEST_PATH
  to_unix $STAGE_PATH STAGE_PATH

  echo "DEST_PATH=\"$DEST_PATH\""   > $PRODUCT_DIR/${APP}.val
  echo "SRC_PATH=\"$SRC_PATH\""     >> $PRODUCT_DIR/${APP}.val
  echo "STAGE_PATH=\"$STAGE_PATH\"" >> $PRODUCT_DIR/${APP}.val
  echo "REBOOT=\"$REBOOT\""         >> $PRODUCT_DIR/${APP}.val
  echo "LOCALE_SET=\"$LOCALE_SET\"" >> $PRODUCT_DIR/${APP}.val
  # echo "REP_UTIL=\"$REP_UTIL\""     >> $PRODUCT_DIR/${APP}.val
  echo "SOCKS_MON=\"$SOCKS_MON\""   >> $PRODUCT_DIR/${APP}.val
  echo "CONF_CLIENT=\"$CONF_CLIENT\"" >> $PRODUCT_DIR/${APP}.val

}

# ----------------------------------------------------------------------
# function: setAttrs()
#
# description: store the target path and owner for when the filepack
#   gets distributed.
# ----------------------------------------------------------------------

setAttrs()
{
  if [ $DEBUG -eq 1 ]; then
    set -x
  fi

  FPoid=`wlookup -r FilePackage "$FILEPACK_NAME"`

  objcall $FPoid addattr targetPath  2>&1 >$NULL
  objcall $FPoid addattr targetOwner 2>&1 >$NULL

  objcall $FPoid setattr targetPath  "$DEST_PATH"
  objcall $FPoid setattr targetOwner "$OWNER"
}

# ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
# main()
# ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

if [ $# -ne 9 ]; then
  echo "Usage: $0 srcHost srcDir stageDir instDir locale socksmonitor configurationclient reboot source_platform"
  exit 1
fi

SRC_HOST=$1;   shift
SRC_PATH=$1;   shift
STAGE_PATH=$1; shift
DEST_PATH=$1;  shift
LOCALE_SET=$1; shift
# REP_UTIL=$1;   shift
SOCKS_MON=$1;  shift
CONF_CLIENT=$1; shift
REBOOT=$1; shift
SOURCE_PLATFORM=$1

OWNER=root

# to_lower $REP_UTIL  REP_UTIL
to_lower $SOCKS_MON SOCKS_MON
to_lower $CONF_CLIENT CONF_CLIENT
to_lower $REBOOT REBOOT
to_lower $SOURCE_PLATFORM SOURCE_PLATFORM
to_unix $SRC_PATH   SRC_PATH
to_unix $STAGE_PATH STAGE_PATH
to_unix $DEST_PATH  DEST_PATH
to_unix $INST_DIR   INST_DIR

LINK_TO="File Packages"

checkArgs
makeNested
if [ "$SOURCE_PLATFORM" = "nt" ] ; then
  makeExport
else
  makeExportaix
fi

setVal
updateISSfile

echo "Done."
